@@ -7,37 +7,45 @@ import aiohttp
 import requests
 import tqdm
 from bs4 import BeautifulSoup
-from secedgar.client._base import AbstractClient
+from requests.adapters import HTTPAdapter
+from secedgar.exceptions import EDGARQueryError
 from secedgar.utils import make_path
-from secedgar.utils.exceptions import EDGARQueryError
+from urllib3.util.retry import Retry
 
 
-class NetworkClient(AbstractClient):
+class NetworkClient:
     """Class in charge of sending and handling requests to EDGAR database.
 
-    Attributes:
+    Args:
         retry_count (int): Number of times to retry connecting to URL if not successful.
             Defaults to 3.
-        pause (float): Time (in seconds) to wait before retrying if not successful.
-            Defaults to 0.5 seconds.
         batch_size (int): Number of filings to receive per request (helpful if pagination needed).
             Defaults to 10.
+        backoff_factor (float): Backoff factor to use with ``urllib3.util.retry.Retry``.
+            See urllib3 docs for more info. Defaults to 0.
         rate_limit (int): Number of requests per second to limit to.
             Defaults to 10.
+        user_agent (str): Value used for HTTP header "User-Agent" for all requests.
+            Defaults to "github.com/sec-edgar/sec-edgar"
 
     .. note:
-       It is highly suggested to keep rate_limit and batch_size <= 10, as the SEC will block your IP
+       It is highly suggested to keep rate_limit <= 10, as the SEC will block your IP
        temporarily if you exceed this rate.
     """
 
     _BASE = "http://www.sec.gov/"
 
-    def __init__(self, **kwargs):
-        self.retry_count = kwargs.get("retry_count", 3)
-        self.pause = kwargs.get("pause", 0.5)
-        self.batch_size = kwargs.get("batch_size", 10)
-        self.rate_limit = kwargs.get("rate_limit", 10)
-        self.response = None
+    def __init__(self,
+                 retry_count=3,
+                 batch_size=10,
+                 backoff_factor=0,
+                 rate_limit=10,
+                 user_agent="github.com/sec-edgar/sec-edgar"):
+        self.retry_count = retry_count
+        self.batch_size = batch_size
+        self.backoff_factor = backoff_factor
+        self.rate_limit = rate_limit
+        self.user_agent = user_agent
 
     @property
     def retry_count(self):
@@ -52,22 +60,9 @@ class NetworkClient(AbstractClient):
             raise ValueError("Retry count must be greater than 0. Given {0}.".format(value))
         self._retry_count = value
 
-    @property
-    def pause(self):
-        """Amount of time to pause between each unsuccessful request before making another."""
-        return self._pause
-
-    @pause.setter
-    def pause(self, value):
-        if not isinstance(value, (int, float)):
-            raise TypeError("Pause must be int or float. Given type {0}.".format(type(value)))
-        elif value < 0:
-            raise ValueError("Pause must be greater than or equal to 0. Given {0}.".format(value))
-        self._pause = value
-
     @property
     def batch_size(self):
-        """The Number of results to show per page."""
+        """int: The Number of results to show per page."""
         return self._batch_size
 
     @batch_size.setter
@@ -78,6 +73,18 @@ class NetworkClient(AbstractClient):
             raise ValueError("Batch size must be positive integer.")
         self._batch_size = value
 
+    @property
+    def backoff_factor(self):
+        """float: Backoff factor to pass to ``urllib3.util.retry.Retry``."""
+        return self._backoff_factor
+
+    @backoff_factor.setter
+    def backoff_factor(self, value):
+        if not isinstance(value, (int, float)):
+            raise TypeError(
+                "Backoff factor must be int or float. Given type {0}".format(type(value)))
+        self._backoff_factor = value
+
     @property
     def rate_limit(self):
         """int: Number of requests to limit client to per second."""
@@ -90,6 +97,17 @@ class NetworkClient(AbstractClient):
         else:
             self._rate_limit = value
 
+    @property
+    def user_agent(self):
+        """str: Value used for HTTP header "User-Agent" for all requests."""
+        return self._user_agent
+
+    @user_agent.setter
+    def user_agent(self, value):
+        if not isinstance(value, str):
+            raise TypeError("user_agent must be str. Given type {0}.".format(type(value)))
+        self._user_agent = value
+
     @staticmethod
     def _prepare_query(path):
         """Prepare the query url.
@@ -102,8 +120,7 @@ class NetworkClient(AbstractClient):
         """
         return "{base}{path}".format(base=NetworkClient._BASE, path=path)
 
-    @staticmethod
-    def _validate_response(response):
+    def _validate_response(self, response, *args, **kwargs):
         """Ensure response from EDGAR is valid.
 
         Args:
@@ -116,61 +133,44 @@ class NetworkClient(AbstractClient):
                           "No matching Ticker Symbol.",
                           "No matching CIK.",
                           "No matching companies.")
-
         status_code = response.status_code
 
-        if 400 <= status_code < 500:
-            if status_code == 400:
-                raise EDGARQueryError("The query could not be completed. "
-                                      "The page does not exist.")
-            elif status_code == 429:
-                raise EDGARQueryError("Error: You have hit the rate limit. "
-                                      "SEC has banned your IP for 10 minutes. "
-                                      "Please wait 10 minutes "
-                                      "before making another request."
-                                      "https://www.sec.gov/privacy.htm#security")
-            else:
-                raise EDGARQueryError("The query could not be completed. "
-                                      "There was a client-side error with your "
-                                      "request.")
-        elif 500 <= status_code < 600:
-            raise EDGARQueryError("The query could not be completed. "
-                                  "There was a server-side error with "
-                                  "your request.")
-        elif any(error_message in response.text for error_message in error_messages):
-            raise EDGARQueryError()
-        # Need to check for error messages before checking for 200 status code
-        elif status_code != 200:
-            raise EDGARQueryError()
+        if status_code == 429:
+            response.reason = """Error: You have hit the rate limit.
+            SEC has banned your IP for 10 minutes.
+            Please wait 10 minutes before making another request.
+            https://www.sec.gov/privacy.htm#security"""
+        elif any(m in response.text for m in error_messages):
+            raise EDGARQueryError("No results were found or the value submitted was not valid.")
 
-    def get_response(self, path, params, **kwargs):
+        return response
+
+    def get_response(self, path, params=None, **kwargs):
         """Execute HTTP request and returns response if valid.
 
         Args:
             path (str): A properly-formatted path
             params (dict): Dictionary of parameters to pass
-            to request.
+                to request. Defaults to None.
+            backoff_factor (float): Backoff factor to pass to ``urllib3.util.Retry``.
+            kwargs: Keyword arguments to pass to ``requests.Session.get``.
 
         Returns:
-            response (requests.Response): A `requests.Response` object.
+            response (requests.Response): A ``requests.Response`` object.
 
         Raises:
             EDGARQueryError: If problems arise when making query.
         """
         prepared_url = self._prepare_query(path)
-        response = None
-        for i in range(self.retry_count + 1):
-            response = requests.get(prepared_url, params=params, **kwargs)
-            try:
-                self._validate_response(response)
-            except EDGARQueryError as e:
-                # Raise query error if on last retry
-                if i == self.retry_count:
-                    raise e
-            finally:
-                time.sleep(self.pause)
-        self.response = response
-        return self.response
+        headers = {"User-Agent": self.user_agent}
+        with requests.Session() as session:
+            retry = Retry(self.retry_count, backoff_factor=self.backoff_factor,
+                          raise_on_status=True)
+            session.mount(self._BASE, adapter=HTTPAdapter(max_retries=retry))
+            session.hooks["response"].append(self._validate_response)
+            response = session.get(prepared_url, params=params,
+                                   headers=headers, **kwargs)
+            return response
 
     def get_soup(self, path, params, **kwargs):
         """Return BeautifulSoup object from response text. Uses lxml parser.
@@ -178,7 +178,7 @@ class NetworkClient(AbstractClient):
         Args:
             path (str): A properly-formatted path
             params (dict): Dictionary of parameters to pass
-            to request.
+                to request.
 
         Returns:
             BeautifulSoup object from response text.
@@ -214,8 +214,12 @@ class NetworkClient(AbstractClient):
                 f.write(contents)
 
         conn = aiohttp.TCPConnector(limit=self.rate_limit)
-        client = aiohttp.ClientSession(
-            connector=conn, headers={'Connection': 'keep-alive'}, raise_for_status=True)
+        headers = {
+            "Connection": "keep-alive",
+            "User-Agent": self.user_agent,
+        }
+        client = aiohttp.ClientSession(connector=conn, headers=headers,
+                                       raise_for_status=True)
 
         def batch(iterable, n):
             length = len(iterable)
