@@ -3,18 +3,18 @@ import datetime
 import os
 import warnings
 
+from secedgar.cik_lookup import CIKLookup
 from secedgar.client import NetworkClient
+from secedgar.exceptions import FilingTypeError
 from secedgar.filings._base import AbstractFiling
-from secedgar.filings.cik_lookup import CIKLookup
 from secedgar.filings.filing_types import FilingType
 from secedgar.utils import sanitize_date
-from secedgar.utils.exceptions import FilingTypeError
 
 
 class Filing(AbstractFiling):
     """Base class for receiving EDGAR filings.
 
-    Attributes:
+    Args:
         cik_lookup (str): Central Index Key (CIK) for company of interest.
         filing_type (secedgar.filings.filing_types.FilingType): Valid filing type enum.
         start_date (Union[str, datetime.datetime], optional): Date before which not to
@@ -24,6 +24,8 @@ class Filing(AbstractFiling):
             Stands for "date before." Defaults to today.
         count (int): Number of filings to fetch. Will fetch up to `count` if that many filings
             are available. Defaults to all filings available.
+        user_agent (str): Value used for HTTP header "User-Agent" for all requests.
+            Defaults to "github.com/sec-edgar/sec-edgar"
         kwargs: See kwargs accepted for :class:`secedgar.client.network_client.NetworkClient`.
 
     .. versionadded:: 0.1.5
@@ -47,11 +49,11 @@ class Filing(AbstractFiling):
         self.start_date = start_date
         self.end_date = end_date
         self.filing_type = filing_type
-        # make CIKLookup object for users if not given
-        self.cik_lookup = cik_lookup
         self.count = count
         # Make default client NetworkClient and pass in kwargs
         self._client = client if client is not None else NetworkClient(**kwargs)
+        # make CIKLookup object for users if not given
+        self.cik_lookup = cik_lookup
 
     @property
     def path(self):
@@ -122,13 +124,13 @@ class Filing(AbstractFiling):
 
     @property
     def cik_lookup(self):
-        """``secedgar.filings.cik_lookup.CIKLookup``: CIKLookupobject."""
+        """``secedgar.cik_lookup.CIKLookup``: CIKLookup object."""
         return self._cik_lookup
 
     @cik_lookup.setter
     def cik_lookup(self, val):
         if not isinstance(val, CIKLookup):
-            val = CIKLookup(val)
+            val = CIKLookup(val, client=self.client)
         self._cik_lookup = val
 
     def get_urls(self, **kwargs):
